@@ -7,27 +7,23 @@ class FiscalYear(ModelSQL, ModelView):
     _name = 'account.fiscalyear'
     out_invoice_sequence = fields.Many2One('ir.sequence.strict',
             'Customer Invoice Sequence', required=True,
-            domain="[('code', '=', 'account.invoice')," \
-                    "['OR', ('company', '=', company)," \
-                    "('company', '=', False)]]",
+            domain=[('code', '=', 'account.invoice'),
+                ['OR', "('company', '=', company)", ('company', '=', False)]],
                     context="{'code': 'account.invoice', 'company': company}")
     in_invoice_sequence = fields.Many2One('ir.sequence.strict',
             'Supplier Invoice Sequence', required=True,
-            domain="[('code', '=', 'account.invoice')," \
-                    "['OR', ('company', '=', company)," \
-                    "('company', '=', False)]]",
+            domain=[('code', '=', 'account.invoice'),
+                ['OR', "('company', '=', company)", ('company', '=', False)]],
                     context="{'code': 'account.invoice', 'company': company}")
     out_credit_note_sequence = fields.Many2One('ir.sequence.strict',
             'Customer Credit Note Sequence', required=True,
-            domain="[('code', '=', 'account.invoice')," \
-                    "['OR', ('company', '=', company)," \
-                    "('company', '=', False)]]",
+            domain=[('code', '=', 'account.invoice'),
+                ['OR', "('company', '=', company)", ('company', '=', False)]],
                     context="{'code': 'account.invoice', 'company': company}")
     in_credit_note_sequence = fields.Many2One('ir.sequence.strict',
             'Supplier Credit Note Sequence', required=True,
-            domain="[('code', '=', 'account.invoice')," \
-                    "['OR', ('company', '=', company)," \
-                    "('company', '=', False)]]",
+            domain=[('code', '=', 'account.invoice'),
+                ['OR', "('company', '=', company)", ('company', '=', False)]],
                     context="{'code': 'account.invoice', 'company': company}")
 
     def __init__(self):
@@ -82,32 +78,32 @@ class Period(ModelSQL, ModelView):
     _name = 'account.period'
     out_invoice_sequence = fields.Many2One('ir.sequence.strict',
             'Customer Invoice Sequence',
-            domain="[('code', '=', 'account.invoice')]",
-            context="{'code': 'account.invoice'}",
+            domain=[('code', '=', 'account.invoice')],
+            context={'code': 'account.invoice'},
             states={
                 'required': "type == 'standard'",
                 'invisible': "type != 'standard'",
             })
     in_invoice_sequence = fields.Many2One('ir.sequence.strict',
             'Supplier Invoice Sequence',
-            domain="[('code', '=', 'account.invoice')]",
-            context="{'code': 'account.invoice'}",
+            domain=[('code', '=', 'account.invoice')],
+            context={'code': 'account.invoice'},
             states={
                 'required': "type == 'standard'",
                 'invisible': "type != 'standard'",
             })
     out_credit_note_sequence = fields.Many2One('ir.sequence.strict',
             'Customer Credit Note Sequence',
-            domain="[('code', '=', 'account.invoice')]",
-            context="{'code': 'account.invoice'}",
+            domain=[('code', '=', 'account.invoice')],
+            context={'code': 'account.invoice'},
             states={
                 'required': "type == 'standard'",
                 'invisible': "type != 'standard'",
             })
     in_credit_note_sequence = fields.Many2One('ir.sequence.strict',
             'Supplier Credit Note Sequence',
-            domain="[('code', '=', 'account.invoice')]",
-            context="{'code': 'account.invoice'}",
+            domain=[('code', '=', 'account.invoice')],
+            context={'code': 'account.invoice'},
             states={
                 'required': "type == 'standard'",
                 'invisible': "type != 'standard'",
@@ -168,8 +164,8 @@ class Period(ModelSQL, ModelView):
                             period[sequence].id != \
                             vals[sequence]:
                         if invoice_obj.search(cursor, user, [
-                            ('date', '>=', period.start_date),
-                            ('date', '<=', period.end_date),
+                            ('invoice_date', '>=', period.start_date),
+                            ('invoice_date', '<=', period.end_date),
                             ('number', '!=', False),
                             ('type', '=', sequence[:-9]),
                             ], context=context):
